import numpy as np
from skimage.color import rgb2gray
from skimage.exposure import match_histograms
from skimage.metrics import structural_similarity

def encontrar_diferenca(imagem1, imagem2):
    assert imagem1.shape == imagem2.shape, "Especifique 2 imagens com a mesma forma."
    imagem_cinza1 = rgb2gray(imagem1)
    imagem_cinza2 = rgb2gray(imagem2)
    (score, diferenca_de_imagem) = structural_similarity(imagem_cinza1, imagem_cinza2, full=True)
    print("A Similaridade das Imagens é: ", score)
    diferenca_de_imagem_normalizada = (diferenca_de_imagem-np.min(diferenca_de_imagem))/(np.max(diferenca_de_imagem)-np.min(diferenca_de_imagem))
    return diferenca_de_imagem_normalizada

def transferir_histograma(imagem1, imagem2):
    imagem_correspondente = match_histograms(imagem1, imagem2, multichannel=True)
    return imagem_correspondente


from setuptools import setup, find_packages

with open("README.md", "r") as f:           # Aponta para página com a descrição longa da descrição do pacote
    page_description = f.read()

with open("requirements.txt") as f:         # Aponta para o carregamento automático dos requerimentos para uso do pacote
    requirements = f.read().splitlines()

setup(
    name = "gerdison_imagem_processo",
    version = "0.0.1",
    author = "Gerdison",
    author_email = "gerdison.dona@gmail.com",
    description = "Pacote de Processamento de imagens",
    long_description = page_description,
    long_description_content_type = "text/markdown",
    packages = find_packages(),
    install_requires = requirements,
    python_requires = '>=3.8',
)
